// usage: node '--loader=@tapjs/processinfo/esm' foo.mjs
import { parse } from 'path';
import { fileURLToPath } from 'url';
import { getExclude } from './get-exclude.js';
import { getProcessInfo } from './get-process-info.js';
import { saveLineLengths } from './line-lengths.js';
import { resolve } from './require-resolve.js';
// copy main module so that we can --loader=@tapjs/processinfo and use
// this as the entry point as well.
export * from './index.js';
let PORT = undefined;
export const globalPreload = (context) => {
    // this will be something like path/to/dist/mjs/lib/esm.mjs
    // but we need path/to/dist/cjs/cjs.js
    const base = resolve('../cjs/cjs.js');
    const { port } = context || {};
    PORT = port;
    return `
if (typeof port !== 'undefined') {
  const { createRequire, findSourceMap } = getBuiltin('module')
  const { fileURLToPath } = getBuiltin('url')
  const require = createRequire(${JSON.stringify(base)})
  const { getProcessInfo } = require('./get-process-info.js')
  const { saveLineLengths } = require('./line-lengths.js')
  // must be called eagerly here.
  // this does all the registration as well.
  const processInfo = getProcessInfo()
  port.onmessage = (e) => {
    const { filename, content } = e.data
    processInfo.files.push(filename)
    saveLineLengths(filename, content)
  }
  port.unref()
}
`;
};
const exclude = getExclude('_TAPJS_PROCESSINFO_EXCLUDE_', false);
const record = (url, content) => {
    const filename = url.startsWith('file://') ? fileURLToPath(url) : url;
    if (exclude.test(filename))
        return;
    if (PORT) {
        PORT.postMessage({ filename, content });
    }
    else {
        // call lazily so we don't double-register
        getProcessInfo().files.push(filename);
        if (content)
            saveLineLengths(filename, content);
    }
};
export const load = async (url, context, nextLoad) => {
    if (url.startsWith('file://')) {
        const filename = fileURLToPath(url);
        const { ext } = parse(filename);
        // Package bins will sometimes have an extensionless bin script
        // instead of just naming their extensioned file and letting npm
        // symlink it for them. Don't blow up when this happens, just tell
        // node that it's commonjs.
        if (!ext) {
            record(url);
            return {
                format: 'commonjs',
                shortCircuit: true,
            };
        }
    }
    const ret = await nextLoad(url, context);
    record(url, String(ret.source));
    return ret;
};
//# sourceMappingURL=esm.mjs.map